import type { JwkJson } from './Jwk';
import type { JwaEncryptionAlgorithm } from '../jwa/alg';
import { KeyType } from '../../KeyType';
import { JwaCurve, JwaKeyType } from '../jwa';
import { JwaSignatureAlgorithm } from '../jwa/alg';
import { Jwk } from './Jwk';
export declare class P256Jwk extends Jwk {
    static readonly supportedEncryptionAlgorithms: JwaEncryptionAlgorithm[];
    static readonly supportedSignatureAlgorithms: JwaSignatureAlgorithm[];
    static readonly keyType = KeyType.P256;
    private readonly affinePoint;
    constructor({ x, y }: {
        x: string | Uint8Array;
        y: string | Uint8Array;
    });
    get kty(): JwaKeyType.EC;
    get crv(): JwaCurve.P256;
    get x(): string;
    get y(): string;
    /**
     * Returns the uncompressed public key of the P-256 JWK.
     */
    get publicKey(): Uint8Array;
    /**
     * Returns the compressed public key of the P-256 JWK.
     */
    get publicKeyCompressed(): Uint8Array;
    get keyType(): KeyType;
    get supportedEncryptionAlgorithms(): JwaEncryptionAlgorithm[];
    get supportedSignatureAlgorithms(): JwaSignatureAlgorithm[];
    toJson(): P256JwkJson;
    static fromJson(jwkJson: JwkJson): P256Jwk;
    static fromPublicKey(publicKey: Uint8Array): P256Jwk;
}
export interface P256JwkJson extends JwkJson {
    kty: JwaKeyType.EC;
    crv: JwaCurve.P256;
    x: string;
    y: string;
    use?: 'sig' | 'enc';
}
export declare function isValidP256JwkPublicKey(jwk: JwkJson): jwk is P256JwkJson;
